@@ -2,13 +2,16 @@ package Test::Class::Moose::Report::Method;
 
 # ABSTRACT: Reporting on test methods
 
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use 5.010000;
 
-our $VERSION = '0.98';
+our $VERSION = '0.99';
 
 use Moose;
 use Carp;
-use namespace::autoclean;
 use Test::Class::Moose::AttributeRegistry;
 
 with qw(
@@ -53,8 +56,8 @@ sub plan {
 
 sub has_tag {
     my ( $self, $tag ) = @_;
-    croak("has_tag(\$tag) requires a tag name") unless defined $tag;
-    my $class  = $self->instance->class->name;
+    croak('has_tag(\$tag) requires a tag name') unless defined $tag;
+    my $class  = $self->instance->name;
     my $method = $self->name;
     return Test::Class::Moose::AttributeRegistry->method_has_tag(
         $class,
@@ -79,7 +82,7 @@ Test::Class::Moose::Report::Method - Reporting on test methods
 
 =head1 VERSION
 
-version 0.98
+version 0.99
 
 =head1 DESCRIPTION
 
@@ -148,7 +151,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 - 2019 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2021 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
