@@ -2,14 +2,17 @@ package Test::Class::Moose::Report::Time;
 
 # ABSTRACT: Reporting object for timing
 
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use 5.010000;
 
-our $VERSION = '0.98';
+our $VERSION = '0.99';
 
 use Moose;
 use Benchmark qw(timestr :hireswallclock);
 use List::Util qw( max );
-use namespace::autoclean;
 
 {
     my @fields = qw( real user system );
@@ -57,7 +60,7 @@ Test::Class::Moose::Report::Time - Reporting object for timing
 
 =head1 VERSION
 
-version 0.98
+version 0.99
 
 =head1 DESCRIPTION
 
@@ -124,7 +127,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 - 2019 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2021 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
