@@ -8,7 +8,7 @@ use namespace::autoclean;
 
 use 5.010000;
 
-our $VERSION = '0.98';
+our $VERSION = '0.99';
 
 use Carp;
 
@@ -18,6 +18,8 @@ use Test::Class::Moose::AttributeRegistry;
 
 BEGIN {
     require Test::Class::Moose;
+    ## no critic (BuiltinFunctions::ProhibitStringyEval, ErrorHandling::RequireCheckingReturnValueOfEval)
+    ## no critic (Subroutines::ProtectPrivateSubs)
     eval Test::Class::Moose->__sub_attr_declaration_code;
     croak($@) if $@;
 }
@@ -42,7 +44,8 @@ sub import {
 
     $_->import::into($caller) for @imports;
 
-    no strict "refs";
+    ## no critic (TestingAndDebugging::ProhibitNoStrict)
+    no strict 'refs';
     *{"$caller\::Tags"}  = \&Tags;
     *{"$caller\::Test"}  = \&Test;
     *{"$caller\::Tests"} = \&Tests;
@@ -62,7 +65,7 @@ Test::Class::Moose::Role - Test::Class::Moose for roles
 
 =head1 VERSION
 
-version 0.98
+version 0.99
 
 =head1 DESCRIPTION
 
@@ -150,7 +153,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 - 2019 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2021 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
