@@ -1,5 +1,9 @@
 package Foo;
 
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use Test::Class::Moose bare => 1;
 
 use Test2::V0 '!meta';
