@@ -1,5 +1,9 @@
 package ClassD;
 
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use Test::Class::Moose;
 
 sub test_d {
