@@ -1,4 +1,9 @@
 package TestsFor::Basic::Subclass;
+
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use Test::Class::Moose extends => 'TestsFor::Basic';
 
 sub test_me {
@@ -14,7 +19,7 @@ before 'test_this_baby' => sub {
 };
 
 sub this_should_not_run : Tags(first) {
-    fail "We should never see this test";
+    fail 'We should never see this test',;
 }
 
 sub test_this_should_be_run : Tags(second) {
